=======================
The ``atelier`` package
=======================




.. image:: https://readthedocs.org/projects/atelier/badge/?version=latest
   :target: http://atelier.readthedocs.io/en/latest/?badge=latest
.. image:: https://coveralls.io/repos/github/lino-framework/atelier/badge.svg?branch=master
   :target: https://coveralls.io/github/lino-framework/atelier?branch=master
.. image:: https://travis-ci.org/lino-framework/atelier.svg?branch=master
   :target: https://travis-ci.org/lino-framework/atelier?branch=master
.. image:: https://img.shields.io/pypi/v/atelier.svg
   :target: https://pypi.python.org/pypi/atelier/
.. image:: https://img.shields.io/pypi/l/atelier.svg
   :target: https://pypi.python.org/pypi/atelier/

`atelier` is a collection of tools for managing and maintaining
Python software projects.

It contains:

- some general Python utilities
  (`atelier.utils <http://atelier.lino-framework.org/api/atelier.utils.html>`_)
- a library for generating reStructuredText from Python
  (`atelier.rstgen <http://atelier.lino-framework.org/api/atelier.rstgen.html>`_)
- some Sphinx extensions
  (`atelier.sphinxconf <http://atelier.lino-framework.org/api/atelier.sphinxconf.html>`_)
- a library of invoke commands
  (`atelier.invlib <http://atelier.lino-framework.org/api/atelier.invlib.html>`_)
- a minimalistic project management
  (`atelier.projects <http://atelier.lino-framework.org/api/atelier.projects.html>`_)

The central project homepage is http://atelier.lino-framework.org


